@@ -197,5 +197,5 @@ class GPCParser(StatementParser):
 class GPCPlugin(Plugin):
     def get_parser(self, fin):
         encoding = self.settings.get('charset', 'windows-1250')
-        inf = open(fin, encoding=encoding)
-        return GPCParser(inf)
+        inf = open(fin, 'rb')
+        return GPCParser(inf, encoding=encoding)
